Release notes — Transifex v0.9.0 documentation

# Transifex v0.9.0 documentation

# Release notes

Releases notes for the official Transifex releases. Each release note will tell you what’s new in each version, and will also describe any backwards-incompatible changes made in that version.

## Transifex releases

- Transifex version 0.9.x release notes
  - Transifex 0.9 (Mojo)
  - Transifex 0.9 Development Releases
- Transifex version 0.8.x release notes
  - Transifex 0.8 (Magneto)
  - Transifex 0.8 Development Releases
- Transifex version 0.7.x release notes
  - Transifex 0.7 (Pyro) 火
  - Transifex 0.7.1 (Frenzy)
  - Transifex 0.7.2 (Basilisk)
  - Transifex 0.7.3 (Quicksilver)
  - Transifex 0.7.4 (Xorn)
  - Transifex 0.7 Release Candidates
- Transifex version 0.6.x release notes
  - Transifex 0.6 (Apocalypse)
- Transifex version 0.5.x release notes
  - Transifex 0.5 (Gold)
  - Transifex 0.5.1 (Aurora)
  - Transifex 0.5.2 (Wendigo)
- Transifex version 0.4.x release notes
  - Version 0.4 (skipped)
- Transifex version 0.3.x release notes
  - Version 0.3 “Get smart”
  - Version 0.3.1 “A Clockwork Orange”
  - Version 0.3.2 “As Good as It Gets”

## What’s with all the strange names?

Each release marks a huge amount of effort and hours by many people, and includes a number of features, which, when combined, produce a landmark in the development of Transifex. So we give them names, which have some common attribute with the release.

Transifex releases are named after X-Men villains. These are bad guys from the X-men series of comics. For more information, check out the X-Men Wikipedia Article as well as the links provided inside each release notes to the respective villain.

During the 0.3 release cycle (also known as the Turbogears or simply Stone Age), releases were named after movies.